%global debug_package %{nil}
%global shortname clc

Summary:        An open source implementation of the OpenCL 1.1 library requirements
Name:           libclc
Version:        17.0.6 
Release:        2%{?dist}
License:        Apache-2.0 WITH LLVM-exception OR BSD OR MIT
URL:            https://libclc.llvm.org
Source0:        https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/libclc-%{version}.src.tar.xz

BuildRequires:  cmake python-unversioned-command spirv-llvm-translator-tools
BuildRequires:  libedit-devel zlib-devel gnupg2
BuildRequires:  clang-devel >= %{version}
BuildRequires:  llvm-devel >= %{version}
ExcludeArch: loongarch64

%description
libclc is an open source, BSD licensed implementation of the library
requirements of the OpenCL C programming language, as specified by the
OpenCL 1.1 Specification. The following sections of the specification
impose library requirements:

  * 6.1: Supported Data Types
  * 6.2.3: Explicit Conversions
  * 6.2.4.2: Reinterpreting Types Using as_type() and as_typen()
  * 6.9: Preprocessor Directives and Macros
  * 6.11: Built-in Functionsj
  * 9.3: Double Precision Floating-Point
  * 9.4: 64-bit Atomics
  * 9.5: Writing to 3D image memory objects
  * 9.6: Half Precision Floating-Point

libclc is intended to be used with the Clang compiler's OpenCL frontend.

libclc is designed to be portable and extensible. To this end, it provides
generic implementations of most library requirements, allowing the target
to override the generic implementation at the granularity of individual
functions.

libclc currently only supports the PTX target, but support for more
targets is welcome.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -n libclc-%{version}.src -p2

%build
export CFLAGS="%{build_cflags} -D__extern_always_inline=inline"
%set_build_flags
%cmake -DCMAKE_INSTALL_DATADIR:PATH=%{_lib}

%cmake_build

%install
%cmake_install

%check
# The external-calls-clspv--.bc testcase test fails
%cmake_build --target test || :

%files
%license LICENSE.TXT
%doc README.TXT CREDITS.TXT
%dir %{_libdir}/%{shortname}
%{_libdir}/%{shortname}/*.bc
%{_libdir}/%{shortname}/spirv-mesa3d-.spv
%{_libdir}/%{shortname}/spirv64-mesa3d-.spv

%files devel
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{shortname}

%changelog
* Thu Jul 25 2024 Pengda Dou <doupengda@loongson.cn> - 17.0.6-2
- [Type] other
- [DESC] add loongarch64 to ExcludeArch

* Mon Dec 18 2023 Upgrade Robot <upbot@opencloudos.org> - 17.0.6-1
- Upgrade to version 17.0.6

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 16.0.6-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 07 2023 kianli <kianli@tencent.com> - 16.0.6-1
- Initial build

